@@ -2,7 +2,7 @@
 Cucumber result to Jira Xray Test repository
 
 """
-__version__ = "0.5.3"
+__version__ = "0.5.5"
 
 
 import datetime
@@ -12,6 +12,7 @@ import cujirax.xray.import_results as result
 import cujirax.xray.import_tests as test
 from cujirax.cucumber import Element
 from cujirax.jira import Jirakey, JiraX, Project
+from loguru import logger
 
 
 class CuJiraX:
@@ -105,6 +106,8 @@ class CuJiraX:
                 'tests': tests,
                 'test_environments': self.result_info.testEnvironments
             })
+
+            logger.info(output)
             
             test_cases = [n for n in map(lambda x: self._new_testcase(x, self.jira_project, ticket_ts, self.parent_testset_key), new)]
             test.bulk_import(test_cases) if test_cases else None
@@ -123,7 +126,8 @@ class CuJiraX:
                 )
                 res = result.import_xray_json_results(req)
                 output.update({
-                    'import_status': res.status_code
+                    'import_result_status': res.status_code,
+                    'import_result_response': res.json()
                 })
         return output    
         
@@ -164,10 +168,14 @@ class CuJiraX:
         for el in elements:
             test_name = cls.scenarioid_to_tescasename(el.id, el.keyword)
             tests = j.get_tests(test_name)
+
             if tests and not ignore_duplicate:
                 if len(tests) > 1:
+                    logger.error(test_name)
+                    logger.error(["{}".format(t) for t in tests])
                     raise ValueError("More than 1 test key detected: ", tests, test_name)
-            print("[searching]", test_name, tests)
+            logger.info("search test case: " + test_name)
+            logger.info(tests)
             found.append(el) if j.get_tests(test_name) else not_found.append(el)
 
         return found, not_found
